WasmTy

Trait WasmTy 

pub trait WasmTy:
    Copy
    + Send
    + Sync
    + 'static { }
A primitive Wasm type usable as a typed function parameter or result.

This trait is effectively sealed: it is implemented only for the primitive Wasm types (i32, i64, f32, f64, and the unsigned integer aliases).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl WasmTy for f32

Source

impl WasmTy for f64

Source

impl WasmTy for i32

Source

impl WasmTy for i64

Source

impl WasmTy for u32

Source

impl WasmTy for u64

Implementors